function MonteCarlo_Diet = f_DietPreference_Readjust_04052014(PEDIGREE, MonteCarlo_Diet, Production)
% readjust functional group clusters within a Monte Carlo diet 
% assume diet preference for a group within a functional group cluster is proportional 
% to its production rate relative to all other groups within that cluster
% by J. Ruzicka
% takes
%       PEDIGREE.PreyGuild_code         (diet row addresses of all groups in cluster; cluster is set of similar functional groups)
%       PEDIGREE.PreferenceRules        (identify cells that are NOT changed based on Production; cells not changed are 0)
%       PEDIGREE.PedigreeDiet           (use to get the header codes)
%       MonteCarlo_Diet                 (Monte Carlo diet with no row nor column headers)
%       Production                      (production rate of each functional group) (vertical vector)
% returns:
%       MonteCarlo_Diet                 (readjusted diet matrix)
% calls:
%       none
% revision date: 4-05-2014


% *************************************************************************
% STEP 1: read original variable structure values--------------------------
PreyGuild_code         = PEDIGREE.PreyGuild_code;
prey_codes             = PEDIGREE.PedigreeDiet(2:end, 1); % these are AggregationCode numbers (HAS import row at prey_codes = 0); top header row is now trimmed off
PreferenceRules        = PEDIGREE.PedigreeDietPrefRules(2:end, 2:end);
[num_PreyGuilds, toss] = size(PreyGuild_code);





% *************************************************************************
% STEP 2: readjust each set of prey_guild rows in the MonteCarlo_Diet------
for guild_loop = 1:num_PreyGuilds
    
    % step 2a: re-weight prey-guild role in each predator diet by prey production fractions
    current_guild               = PreyGuild_code{guild_loop, :}; % (horizontal vector)
    looky_guild                 = find(ismember(prey_codes, current_guild)); % row addresses of current prey guild in diet (QQQ wrong because of NaN row in prey_codes???)
    
    ClusterDiet                 = MonteCarlo_Diet(looky_guild, :); % (2D matrix: guild size X cluster_clms)
    [cluster_rows cluster_clms] = size(ClusterDiet);
    total_Diet                  = sum(ClusterDiet, 1); % total contribution cluster in diet of all consumers; (horizontal vector: 1 X cluster_clms)
    
    cluster_Production          = Production(looky_guild); % production rate of each group in cluster (vertical vector: cluster_rows); does not include a row that corresponds to import in diet
    total_cluster_Production    = sum(cluster_Production); % (scaler)
    fraction_Production         = cluster_Production ./ total_cluster_Production; % contribution of each functional group to total cluster production (vertical vector: cluster_rows)

    new_ClusterDiet            = repmat(total_Diet, [cluster_rows, 1]) .* repmat(fraction_Production, [1, cluster_clms]); % prey-guild role in each predator diet re-weighted by prey production fractions
    
    % step 2b: correct for zeros in diet ----------------------------------
    %          prevent zeros in diets from becoming other than zero
    looky_zeros                  = find(ClusterDiet == 0);
    new_ClusterDiet(looky_zeros) = 0;
    sum_new_ClusterDiet          = sum(new_ClusterDiet, 1); % (horizontal vector: 1 X cluster_clms)
        
    new_ClusterDiet              = (new_ClusterDiet ./ repmat(sum_new_ClusterDiet, [cluster_rows, 1])) .* repmat(total_Diet, [cluster_rows, 1]);
    new_ClusterDiet(isnan(new_ClusterDiet)) = 0; % correct for div/0

    % step 2c: don't change consumers where diet is not variable ----------
    cluster_PreferenceRules = PreferenceRules(looky_guild, :); % (2D matrix: cluster_rows X cluster_clms)
    zero_clms               = min(cluster_PreferenceRules, [], 1); % do this to automatically set columns to 0 in case I missed individual cells in rule matrix (if its 0 for one prey then it should be 0 for all prey)
    looky_zero              = find(zero_clms == 0);
    new_ClusterDiet(:, looky_zero) = ClusterDiet(:, looky_zero); % replace clms of new_ClusterDiet with original ClusterDiet values for predators where diet preference re-scaling is not to be applied
    
    % step 2d: place readjusted prey-guild rows back into MonteCarlo_Diet -
    MonteCarlo_Diet(looky_guild, :) = new_ClusterDiet;
    
end % (guild_loop)

% end m-file***************************************************************