function [Production_MonteCarlo EnergyBudget_MonteCarlo] = f_E2E_MonteCarlo_09052013(MonteCarloConditions)
% generate MonteCarlo Production Matrices and production estimates
% by drawing from a uniform distribution about each element of the EnergyBudget_matrix
% by Jim Ruzicka
% calls:
%	f_WebProductivityWLoss
% takes:
%       MonteCarloConditions.EnergyBudget_matrix      (EM & BA rows already deleted; benthic detritus flowing to benthic detritus should be 0)
%       MonteCarloConditions.num_trials
%       MonteCarloConditions.pedigree
%       MonteCarloConditions.TransferEfficiency
%       MonteCarloConditions.PhysicalLossFraction
%       MonteCarloConditions.InputProductionVector_Base
% returns:
%       EnergyBudget_MonteCarlo			(all Monte Carlo production arrays)
%       Production_MonteCarlo			(production vector of each Monte Carlo model)
% revision date: 9-5-2013





% *************************************************************************
% STEP 1: set operating conditions-----------------------------------------
default_pedigree = 0.5; % if pedigree = [], default is CV = 0.5





% *************************************************************************
% STEP 2: unpack variables (leave original variable structures unchanged)
[E2E_rows, E2E_clms, E2E_layers] = size(MonteCarloConditions.EnergyBudget_matrix);
EnergyBudget_matrix              = MonteCarloConditions.EnergyBudget_matrix(1:E2E_rows, 1:E2E_clms, 1); % this must be a single 2D production matrix, choose top matrix in case this is a stack of MonteCarlo models (QQQ in future, make sure top matrix is the "type" base model)
num_trials                       = MonteCarloConditions.num_trials; % number of trials to run
pedigree                         = MonteCarloConditions.pedigree; % set CV about which to sample cells in base_EnergyBudget_matrix; 
TransferEfficiency               = MonteCarloConditions.TransferEfficiency;
PhysicalLossFraction             = MonteCarloConditions.PhysicalLossFraction;
InputProductionVector            = MonteCarloConditions.InputProductionVector;





% *************************************************************************
% STEP 3: determine if using a pedigree from a set of MonteCarlo runs or if using a manually defined CV


% step 3b: evaluate pedigree
[Pedigree_rows, Pedigree_clms] = size(pedigree);

if Pedigree_rows == 0
    EnergyBudget_matrix_CV = ones(E2E_rows, E2E_clms) .* default_pedigree; % use default pedigree if not previously defined
elseif Pedigree_rows == 1
    EnergyBudget_matrix_CV = ones(E2E_rows, E2E_clms) .* pedigree; % use provided (scaler) pedigree value
elseif Pedigree_rows > 1
    EnergyBudget_matrix_CV = pedigree;
end





% *************************************************************************
% STEP 4: prepare to create MonteCarlo arrays------------------------------
% step 4a: initialize result arrays
EnergyBudget_MonteCarlo = zeros(E2E_rows, E2E_clms, num_trials);
Production_MonteCarlo   = zeros(E2E_clms, num_trials);

% step 4b: calculate interval over which to draw random EnergyBudget_matrix based on the ECOTRANS pedigree
interval_low  = EnergyBudget_matrix - (EnergyBudget_matrix .* EnergyBudget_matrix_CV);
interval_high = EnergyBudget_matrix + (EnergyBudget_matrix .* EnergyBudget_matrix_CV);

% step 4c: weed out any interval values < 0 or > 1 and reset to 0 or 1
interval_low(interval_low < 0)   = 0;
interval_high(interval_high < 0) = 0;
interval_low(interval_low > 1)   = 1;
interval_high(interval_high > 1) = 1;





% *************************************************************************
% STEP 5: generate random models and production vectors--------------------
for trial_loop = 1:num_trials
    
    % step 5a: generate a random matrix (cells are random values between 0 and 1)
    random_matrix = rand(E2E_rows, E2E_clms); % draw from UNIFORM distribution

    % step 5b: produce the new random production matrix
    MonteCarloArray = interval_low + (interval_high - interval_low) .* random_matrix;
    
    % step 5c: re-scale each producer column to column sum of the original "type" EnergyBudget_matrix
    sum_MonteCarlo      = sum(MonteCarloArray, 1);
    sum_original_matrix = sum(EnergyBudget_matrix, 1);
    for consumer_loop = 1:E2E_rows
        MonteCarloArray(consumer_loop, :) = (MonteCarloArray(consumer_loop, :) ./ sum_MonteCarlo) .* sum_original_matrix; % the term sum(original_matrix, 1) allows for producers in base matrix that do not sum to 1 (i.e., fisheries)
    end
    MonteCarloArray(isnan(MonteCarloArray)) = 0; % filter for NaNs and replace with 0 (eliminate sum_MonteCarlo = div/0 cases)
    
    % step 5d: calculate new productivity vector
    current_Production = f_WebProductivityWLoss(TransferEfficiency, MonteCarloArray, InputProductionVector, PhysicalLossFraction); % calculate the values of production as initial conditions; (g WWT m^(-2) d^(-1)); (horizontal vector)

    % step 5e: store results
    EnergyBudget_MonteCarlo(1:E2E_rows, 1:E2E_clms, trial_loop) = MonteCarloArray;
    Production_MonteCarlo(1:E2E_clms, trial_loop)               = current_Production;
    
end; % (trial_loop)





% end m-file***************************************************************