function [dat] = f_read_EwE_csv_01122015(readFile)
% load EwE model from named .csv file and prepare data
% includes conversion from mortality matrix in K-path to consumption matrix
% by Jim Ruzicka
% calls:
%	none
% takes:
%	readFile                            concatenated directory & file name
% returns:
% number codes & names
%         dat.EcotranNumberCode
%         dat.EcotranGroupType
%         dat.AggCode
%         dat.EwENumberCode
%         dat.EwEName
%         dat.EcotranName
%         dat.AggEwEName
% parameters (vectors)        
%         dat.Biomass
%         dat.Production
%         dat.PB
%         dat.QB
%         dat.EE
%         dat.PQ
%         dat.AE
%         dat.TL
%         dat.landings                  (t km^-2 y^-1)
%         dat.discards                  (t km^-2 y^-1)
%         dat.BA                        (t km^-2 y^-1)
%         dat.EM                        (t km^-2 y^-1)  (-) for immigration; (+) for emigration
% diet & consumption (matrices)
%         dat.diet                      (column 1 & row 1 are trophic group number headers)
%         dat.import_diet               (column 1 is header)
%         dat.consumption               (t km^-2 y^-1) 	(array)
%         dat.import_consumption
%         dat.total_consumption
%         dat.mortality
% ECOTRAN recycling definitions & production parameters
%         dat.DetritusImport
%         dat.EwE_DetritusFate
%         dat.EggProduction             (forced egg, gamete, or live-birth production --- not derived as EwE detritus)
%         dat.Metabolism                (forced metabolism --- not derived from EwE parameters)
%         dat.DetritusFate_feces
%         dat.DetritusFate_senescence
%         dat.ExcretionFate
%         dat.ProductionLossScaler
%         dat.RetentionScaler
%         dat.PelagicBacterialReduction
%         dat.BenthicBacterialReduction
%         dat.Oxidation_NH4
%         dat.PhytoUptake_NH4
%         dat.PhytoUptake_NO3
% numbers of various group types
%         dat.num_living
%         dat.num_detritus
%         dat.num_gear
%         dat.num_EwEGroups
%         dat.num_LivingAndDetritus
%         dat.num_NitrogenNutrients
%         dat.num_NonNitrogenNutrients
%         dat.num_EcotranGroups
%         dat.num_eggs
%         dat.num_EggsAndDetritus
%         dat.num_plgcBacteria
%         dat.num_bnthBacteria
%         dat.num_Bacteria
% group type code definitions
%         dat.GroupTypeDef_ANYNitroNutr
%         dat.GroupTypeDef_NO3
%         dat.GroupTypeDef_plgcNH4
%         dat.GroupTypeDef_bnthNH4
%         dat.GroupTypeDef_ANYPrimaryProd
%         dat.GroupTypeDef_LrgPhyto
%         dat.GroupTypeDef_SmlPhyto
%         dat.GroupTypeDef_Macrophytes
%         dat.GroupTypeDef_ANYConsumer
%         dat.GroupTypeDef_ConsumPlgcPlankton
%         dat.GroupTypeDef_ConsumPlgcNekton
%         dat.GroupTypeDef_ConsumPlgcWrmBlood
%         dat.GroupTypeDef_ConsumBntcInvert
%         dat.GroupTypeDef_ConsumBntcVert
%         dat.GroupTypeDef_ConsumBnthWrmBlood
%         dat.GroupTypeDef_eggs
%         dat.GroupTypeDef_ANYDetritus
%         dat.GroupTypeDef_terminalPlgcDetr
%         dat.GroupTypeDef_offal
%         dat.GroupTypeDef_terminalBnthDetr
%         dat.GroupTypeDef_BA
%         dat.GroupTypeDef_EM
%         dat.GroupTypeDef_fishery
%         dat.GroupTypeDef_import
%         dat.GroupTypeDef_plgcBacteria
%         dat.GroupTypeDef_bnthBacteria
% pedigree information
%         dat.PreyGuild_name
%         dat.PreyGuild_code
%         dat.PedigreeParameters
%         dat.PedigreeLandings
%         dat.PedigreeDiscards
%         dat.PedigreeDiet
%         dat.import_PedigreeDiet
%         dat.PedigreeDietPrefRules
%         dat.import_PedigreeDietPrefRules
%         dat.Pedigree_PhysiologyScaler
%         dat.Pedigree_BiomassScaler
%         dat.Pedigree_FisheriesScaler
%         dat.Pedigree_DietScaler
%         dat.Pedigree_BAScaler
%         dat.Pedigree_EMScaler
%         dat.Pedigree_DiscardScaler
%         dat.Pedigree_minBiomass
%         dat.Pedigree_minPhysiology
% functional response parameters
%         dat.FunctionalResponseParams
%         dat.FunctionalResponse_matrix
% revision date: 1-12-2015





% *************************************************************************
% STEP 1: read model time series .csv file---------------------------------
% read in first column (which contains clm address info for parameters)
fid         = fopen(readFile);
[ModelInfo] = textscan(fid, '%f %*[^\r]', 'delimiter', ',');
fclose(fid);
a           = cell2mat(ModelInfo);
numcols     = sum(a(20:33)) + 13*1; % add 13 to account for 1 blank clm btn each parameter type (14 parameter classes)

fid         = fopen(readFile);
textformat  = ['%f %*f %s %s %s %s %s %*f ', repmat('%f', 1, numcols), '%*[^\r]']; % clm space string string string string space parameters...
indata      = textscan(fid, textformat, 'delimiter', ',', 'CollectOutput', 1);
fclose(fid);





% *************************************************************************
% STEP 2: parse group counts-----------------------------------------------
dat.num_living               = a(1);
dat.num_detritus             = a(2);
dat.num_gear                 = a(3);
dat.num_EwEGroups            = dat.num_living + dat.num_detritus + dat.num_gear;
dat.num_LivingAndDetritus    = dat.num_living + dat.num_detritus;
dat.num_NitrogenNutrients    = a(4);
dat.num_NonNitrogenNutrients = a(5);
dat.num_EcotranGroups        = dat.num_living + dat.num_detritus + dat.num_gear + dat.num_NitrogenNutrients;





% *************************************************************************
% STEP 3: initial parsing of .csv info-------------------------------------
% step 3a: get parameter column addresses start with scalers of parameter type clm length
clms_Parameters            = a(20);
clms_landings              = a(21);
clms_discards              = a(22);
clms_Diet                  = a(23);
clms_Mortalities           = a(24);
clms_DetritusFate          = a(25);
clms_EcotranType           = a(26);
clms_EcotranRecycling      = a(27);
clms_PedigreeParameters    = a(28);
clms_PedigreeLandings      = a(29);
clms_PedigreeDiscards      = a(30);
clms_PedigreeDiet          = a(31);
clms_PedigreeDietPrefRules = a(32);
clms_FunctionalResponse    = a(33);

% step 3b: convert to clm address vectors (note sequential conversion of scalers to vectors)
clms_Parameters            = 1:clms_Parameters;
clms_landings              = (max(clms_Parameters)+2):(max(clms_Parameters)+1+clms_landings);
clms_discards              = (max(clms_landings)+2):(max(clms_landings)+1+clms_discards);
clms_Diet                  = (max(clms_discards)+2):(max(clms_discards)+1+clms_Diet);
clms_Mortalities           = (max(clms_Diet)+2):(max(clms_Diet)+1+clms_Mortalities);
clms_DetritusFate          = (max(clms_Mortalities)+2):(max(clms_Mortalities)+1+clms_DetritusFate);
clms_EcotranType           = (max(clms_DetritusFate)+2):(max(clms_DetritusFate)+1+clms_EcotranType);
clms_EcotranRecycling      = (max(clms_EcotranType)+2):(max(clms_EcotranType)+1+clms_EcotranRecycling);
clms_PedigreeParameters    = (max(clms_EcotranRecycling)+2):(max(clms_EcotranRecycling)+1+clms_PedigreeParameters);
clms_PedigreeLandings      = (max(clms_PedigreeParameters)+2):(max(clms_PedigreeParameters)+1+clms_PedigreeLandings);
clms_PedigreeDiscards      = (max(clms_PedigreeLandings)+2):(max(clms_PedigreeLandings)+1+clms_PedigreeDiscards);
clms_PedigreeDiet          = (max(clms_PedigreeDiscards)+2):(max(clms_PedigreeDiscards)+1+clms_PedigreeDiet);
clms_PedigreeDietPrefRules = (max(clms_PedigreeDiet)+2):(max(clms_PedigreeDiet)+1+clms_PedigreeDietPrefRules);
clms_FunctionalResponse    = (max(clms_PedigreeDietPrefRules)+2):(max(clms_PedigreeDietPrefRules)+1+clms_FunctionalResponse);

% step 3c: parse parameter group types
data_to_parse              = cell2mat(indata(3));
looky_NaN                  = find(data_to_parse == 99999); % find blank cells via blank cell code
data_to_parse(looky_NaN)   = NaN; % replace blank cells with NaN
parameters                 = data_to_parse(1:dat.num_EwEGroups, clms_Parameters);
landings                   = data_to_parse(1:dat.num_LivingAndDetritus, clms_landings);
discards                   = data_to_parse(1:dat.num_LivingAndDetritus, clms_discards);
diet                       = data_to_parse(1:(dat.num_LivingAndDetritus+1), clms_Diet);
mortalities                = data_to_parse(1:dat.num_LivingAndDetritus, clms_Mortalities);
EwE_DetritusFate           = data_to_parse(1:dat.num_EwEGroups, clms_DetritusFate); % note that detritus export column is not read in
EcotranType                = data_to_parse(1:dat.num_EcotranGroups, clms_EcotranType); % note that EM & BA rows are not exported from .xlsm file
EcotranRecycling           = data_to_parse(1:dat.num_EcotranGroups, clms_EcotranRecycling);
PedigreeParameters         = data_to_parse(1:dat.num_LivingAndDetritus, clms_PedigreeParameters);
PedigreeLandings           = data_to_parse(1:dat.num_LivingAndDetritus, clms_PedigreeLandings);
PedigreeDiscards           = data_to_parse(1:dat.num_LivingAndDetritus, clms_PedigreeDiscards);
PedigreeDiet               = data_to_parse(1:(dat.num_LivingAndDetritus+1), clms_PedigreeDiet);
PedigreeDietPrefRules      = data_to_parse(1:(dat.num_LivingAndDetritus+1), clms_PedigreeDietPrefRules);
FunctionalResponseParams   = data_to_parse(1:(dat.num_EcotranGroups), clms_FunctionalResponse);




% *************************************************************************
% STEP 4: parse EcotranType and Aggregation groups-------------------------
dat.EcotranNumberCode = EcotranType(:, 1);
dat.EcotranGroupType  = EcotranType(:, 2);
dat.AggCode           = EcotranType(:, 3);





% *************************************************************************
% STEP 5: parse EcotranRecycling-------------------------------------------
dat.BA                        = EcotranRecycling(:, 1);
dat.EM                        = EcotranRecycling(:, 2);
dat.EggProduction             = EcotranRecycling(:, 3); % defined egg, gamete, or live young production (as opposed to use of eggs as EwE detritus method)
dat.Metabolism                = EcotranRecycling(:, 4); % defined metabolism (as opposed to derivation from EwE params (QQQ for future options)
dat.DetritusFate_feces        = EcotranRecycling(:, 5:6);
dat.DetritusFate_senescence   = EcotranRecycling(:, 7:8);
dat.ExcretionFate             = EcotranRecycling(:, 9:10);
dat.ProductionLossScaler      = EcotranRecycling(:, 11);
dat.RetentionScaler           = EcotranRecycling(:, 12);
dat.PelagicBacterialReduction = a(6);
dat.BenthicBacterialReduction = a(7);
dat.Oxidation_NH4             = a(8:9);
dat.PhytoUptake_NH4           = a(10:14);
dat.PhytoUptake_NO3           = a(15:19);





% *************************************************************************
% STEP 6: parse GroupTypes definitions-------------------------------------
dat.GroupTypeDef_ANYNitroNutr       = a(35);
dat.GroupTypeDef_NO3                = a(36);
dat.GroupTypeDef_plgcNH4            = a(37);
dat.GroupTypeDef_bnthNH4            = a(38);
dat.GroupTypeDef_ANYPrimaryProd     = a(39);
dat.GroupTypeDef_LrgPhyto           = a(40);
dat.GroupTypeDef_SmlPhyto           = a(41);
dat.GroupTypeDef_Macrophytes        = a(42);
dat.GroupTypeDef_ANYConsumer        = a(43);
dat.GroupTypeDef_ConsumPlgcPlankton = a(44);
dat.GroupTypeDef_ConsumPlgcNekton   = a(45);
dat.GroupTypeDef_ConsumPlgcWrmBlood = a(46);
dat.GroupTypeDef_ConsumBntcInvert   = a(47);
dat.GroupTypeDef_ConsumBntcVert     = a(48);
dat.GroupTypeDef_ConsumBnthWrmBlood = a(49);
dat.GroupTypeDef_eggs               = a(50);
dat.GroupTypeDef_ANYDetritus        = a(51); % (not including eggs)
dat.GroupTypeDef_terminalPlgcDetr   = a(52);
dat.GroupTypeDef_offal              = a(53);
dat.GroupTypeDef_terminalBnthDetr   = a(54);
dat.GroupTypeDef_BA                 = a(55); % (biomass accumulation)
dat.GroupTypeDef_EM                 = a(56); % (emigration)
dat.GroupTypeDef_fishery            = a(57);
dat.GroupTypeDef_import             = a(58); % assigned in matlab code later (import??)
dat.GroupTypeDef_plgcBacteria       = a(59);
dat.GroupTypeDef_bnthBacteria       = a(60);



% *************************************************************************
% STEP 7: parse additional group counts------------------------------------
dat.num_eggs                 = length(find(dat.EcotranGroupType  == dat.GroupTypeDef_eggs));
dat.num_detritus             = length(find(floor(dat.EcotranGroupType) == dat.GroupTypeDef_ANYDetritus));
dat.num_EggsAndDetritus      = dat.num_eggs + dat.num_detritus;
dat.num_plgcBacteria         = length(find(dat.EcotranGroupType  == dat.GroupTypeDef_plgcBacteria));
dat.num_bnthBacteria         = length(find(dat.EcotranGroupType  == dat.GroupTypeDef_bnthBacteria));
dat.num_Bacteria             = dat.num_plgcBacteria + dat.num_bnthBacteria;




% *************************************************************************
% STEP 8: parse parameters-------------------------------------------------
dat.EwENumberCode                             = parameters(1:dat.num_EwEGroups, 1);  % fully resolved group code number
dat.TL                                        = parameters(1:dat.num_EwEGroups, 2);
dat.Biomass                                   = parameters(1:dat.num_EwEGroups, 3);
dat.PB                                        = parameters(1:dat.num_EwEGroups, 4);
dat.QB                                        = parameters(1:dat.num_EwEGroups, 5);
dat.EE                                        = parameters(1:dat.num_EwEGroups, 6);
dat.PQ                                        = parameters(1:dat.num_EwEGroups, 7);
dat.AE                                        = 1 - parameters(1:dat.num_EwEGroups, 8); % assimilation efficiency = 1 - NonAssimilation
toss_EwE_BA                                   = parameters(1:dat.num_EwEGroups, 9); % this is BA from EwE main sheet, use definition on EcotranRecycling sheet instead
dat.Production                                = (dat.PB .* dat.Biomass);
dat.Production(isnan(dat.Production))         = 0; % convert any NaNs (detritus groups) into 0; probably not needed
dat.DetritusImport                            = parameters(1:dat.num_EwEGroups, 10); % (t km^-2 y^-1)
dat.DetritusImport(isnan(dat.DetritusImport)) = 0; % convert any NaNs into 0; probably not needed





% *************************************************************************
% STEP 9: parse landings & discards----------------------------------------
dat.landings = landings(1:dat.num_LivingAndDetritus, :);
dat.discards = discards(1:dat.num_LivingAndDetritus, :);





% *************************************************************************
% STEP 10: parse detritus fate----------------------------------------------
dat.EwE_DetritusFate = EwE_DetritusFate(1:dat.num_EwEGroups, :);





% *************************************************************************
% STEP 11: parse diet------------------------------------------------------
dat.diet                            = zeros((dat.num_LivingAndDetritus+1), (dat.num_LivingAndDetritus+1)); % initialize (add 1 row and 1 clm for headers)
dat.import_diet                     = zeros(1, (dat.num_LivingAndDetritus+1)); % initialize (add 1 clm for header)
dat.diet(2:end, 1)                  = dat.EwENumberCode(1:dat.num_LivingAndDetritus); % producer group header
dat.diet(1, 2:end)                  = dat.EwENumberCode(1:dat.num_LivingAndDetritus)'; % consumer group header
dat.diet(1, 1)                      = NaN;
dat.import_diet(1)                  = NaN;
dat.diet(2:(dat.num_LivingAndDetritus+1), 2:(dat.num_LivingAndDetritus+1)) = diet(1:dat.num_LivingAndDetritus, 1:dat.num_LivingAndDetritus); % this final dat.diet does not include import diet
dat.import_diet(2:(dat.num_LivingAndDetritus+1))                           = diet((dat.num_LivingAndDetritus+1), 1:dat.num_LivingAndDetritus); % next last row is import diet





% *************************************************************************
% STEP 12: parse mortalities-----------------------------------------------
dat.mortality                       = zeros((dat.num_LivingAndDetritus+1), (dat.num_LivingAndDetritus+1)); % initialize
dat.mortality(2:end, 1)             = dat.EwENumberCode(1:(dat.num_LivingAndDetritus)); % producer group header
dat.mortality(1, 2:end)             = dat.EwENumberCode(1:(dat.num_LivingAndDetritus))'; % consumer group header
dat.mortality(1, 1)                 = NaN;
dat.mortality(2:(dat.num_LivingAndDetritus+1), 2:(dat.num_living+1)) = mortalities(1:dat.num_LivingAndDetritus, (dat.num_gear+1):(dat.num_gear+dat.num_living));





% *************************************************************************
% STEP 13: create consumption matrix---------------------------------------
% step 13a: begin
production       = dat.Biomass(1:dat.num_living) .* dat.PB(1:dat.num_living); % production by living groups
feces_production = dat.Biomass(1:dat.num_living) .* dat.QB(1:dat.num_living) .* (1 - dat.AE(1:dat.num_living));
total_landings   = sum(dat.landings(1:dat.num_living, :), 2);
dat.consumption  = dat.mortality; % initialize; (array (living + detritus) X (living + detritus) with a row & clm header)

% step 13b: calculate consumption rate (t/km2/y) for all living groups
for consumer_loop = 1:dat.num_living
    dat.consumption(2:(dat.num_living+1), (consumer_loop+1)) = dat.consumption(2:(dat.num_living+1), (consumer_loop+1)) .* dat.Biomass(1:dat.num_living); % consumption = mortality (1/y) * biomass (t/km2)
end

total_consumed          = sum(dat.consumption(2:(dat.num_living+1), 2:(dat.num_living+1)), 2); % total predation upon each living group (vertical vector)
detritus_production     = (production + feces_production) - (total_consumed + total_landings); % detritus production of living groups
total_consumed_detritus = sum(dat.consumption((dat.num_living+2):(dat.num_LivingAndDetritus+1), 2:(dat.num_living+1)), 2); % detritus (incl. eggs) that is consumed by living groups (vertical vector)

% step 13c: calculate flow to detritus
Flow2Detritus = zeros(dat.num_LivingAndDetritus, dat.num_EggsAndDetritus); % initialize; (array; num_LivingAndDetritus X num_EggsAndDetritus)
for detritus_loop = 1:dat.num_EggsAndDetritus
    Flow2Detritus(1:dat.num_living, detritus_loop) = dat.EwE_DetritusFate(1:dat.num_living, detritus_loop) .* detritus_production;
end

% step 13d: calculate fishery discard
discard_detritus = zeros(dat.num_LivingAndDetritus, dat.num_EggsAndDetritus); % initialize; (array; num_LivingAndDetritus X num_EggsAndDetritus)
for fishery_loop = 1:dat.num_gear
    current_Discard       = dat.discards(:, fishery_loop);
    current_DiscardFate   = dat.EwE_DetritusFate((dat.num_LivingAndDetritus + fishery_loop), :); % fisheries in rows of model groups must be in same order as across clms in discards)
    temp_DiscardFateArray = repmat(current_DiscardFate, dat.num_LivingAndDetritus, 1);
    for detritus_loop = 1:dat.num_EggsAndDetritus
        discard_detritus(:, detritus_loop) = discard_detritus(:, detritus_loop) + (temp_DiscardFateArray(:, detritus_loop) .* current_Discard);
    end
end

Flow2Detritus = Flow2Detritus + discard_detritus; % (array: rows (living groups) X clms (detritus groups)) 

% step 13e: calculate detritus flow to other detritus groups
total_Flow2Detritus      = sum(Flow2Detritus, 1); % (horizontal vector)
surplus_detritus         = total_Flow2Detritus' - total_consumed_detritus; % (vertical vector); may have negative values at this point until detritus flow to detritus is included
DetritusToDetritusFate   = dat.EwE_DetritusFate((dat.num_living+1):dat.num_LivingAndDetritus, :);
DetritusToDetritus_array = DetritusToDetritusFate; % initialize (just to get size, all elements will be overwritten)
for detritus_loop = 1:dat.num_EggsAndDetritus
    DetritusToDetritus_array(:, detritus_loop) = surplus_detritus .* DetritusToDetritus_array(:, detritus_loop);
end

% step 13f: put final consumption matrix together
dat.consumption(2:(dat.num_LivingAndDetritus+1), (dat.num_living+2):(dat.num_LivingAndDetritus+1))                  = Flow2Detritus;
dat.consumption((dat.num_living+2):(dat.num_LivingAndDetritus+1), (dat.num_living+2):(dat.num_LivingAndDetritus+1)) = DetritusToDetritus_array;

% step 13g: calculate import consumption (total consumption .* import_diet)
dat.total_consumption(1, 1:(dat.num_LivingAndDetritus+1)) = NaN; % initialize, add 1 cell up front for header
dat.total_consumption(1, 2:end)                           = dat.Biomass(1:dat.num_LivingAndDetritus) .* dat.QB(1:dat.num_LivingAndDetritus); % ignore fisheries at the end
dat.import_consumption                                    = dat.total_consumption .* dat.import_diet; % (import_consumption = total consumption .* import_diet) (horizontal vector; first cell is a header)





% *************************************************************************
% STEP 14: parse group names (& PreyGuild strings)-------------------------
names_to_parse     = indata(2);
names_to_parse     = names_to_parse{1};
dat.EwEName        = names_to_parse(1:dat.num_EwEGroups, 1); % formal EwE trophic group names
dat.EcotranName    = names_to_parse(1:dat.num_EcotranGroups, 2); % formal Ecotran trophic group names
dat.AggEwEName     = names_to_parse(1:dat.num_EcotranGroups, 3); % formal AggEwE trophic group names
dat.PreyGuild_name = names_to_parse(1:20, 4); % excel EwE macro allows only 20 PreyGuilds right now
dat.PreyGuild_code = names_to_parse(1:20, 5); % excel EwE macro allows only 20 PreyGuilds right now

% QQQ switch form of these 2 lines if error occurs - errors caused when vis-basic saves blank excel data as '' or as '0'
dat.PreyGuild_name(strcmp(dat.PreyGuild_name, '0')) = []; % remove empty ('') rows; 1/12/2015 changed from ('') to ('0')
dat.PreyGuild_code(strcmp(dat.PreyGuild_code, '0')) = []; % remove empty ('') rows; keeping these number sets as strings for now; 1/12/2015 changed from ('') to ('0')
% dat.PreyGuild_name(strcmp(dat.PreyGuild_name, '')) = []; % remove empty ('') rows;
% dat.PreyGuild_code(strcmp(dat.PreyGuild_code, '')) = []; % remove empty ('') rows; keeping these number sets as strings for now




% *************************************************************************
% STEP 15: parse pedigree--------------------------------------------------
% step 15a: pedigrees for parameters and fisheries
dat.PedigreeParameters        = PedigreeParameters;
dat.PedigreeLandings          = PedigreeLandings;
dat.PedigreeDiscards          = PedigreeDiscards;

% step 15b: PedigreeDiet
dat.PedigreeDiet                    = zeros((dat.num_LivingAndDetritus+1), (dat.num_LivingAndDetritus+1)); % initialize (add 1 row and 1 clm for headers)
dat.import_PedigreeDiet             = zeros(1, (dat.num_LivingAndDetritus+1)); % initialize (add 1 clm for header)
dat.PedigreeDiet(2:end, 1)          = dat.EwENumberCode(1:dat.num_LivingAndDetritus); % producer group header
dat.PedigreeDiet(1, 2:end)          = dat.EwENumberCode(1:dat.num_LivingAndDetritus)'; % consumer group header
dat.PedigreeDiet(1, 1)              = NaN;
dat.import_PedigreeDiet(1)          = NaN;
dat.PedigreeDiet(2:(dat.num_LivingAndDetritus+1), 2:(dat.num_LivingAndDetritus+1)) = PedigreeDiet(1:dat.num_LivingAndDetritus, 1:dat.num_LivingAndDetritus); % this final dat.PedigreeDiet does not include import diet
dat.import_PedigreeDiet(2:(dat.num_LivingAndDetritus+1))                           = PedigreeDiet((dat.num_LivingAndDetritus+1), 1:dat.num_LivingAndDetritus); % next last row is import PedigreeDiet

% step 15c: PedigreeDietPrefRules
dat.PedigreeDietPrefRules                    = zeros((dat.num_LivingAndDetritus+1), (dat.num_LivingAndDetritus+1)); % initialize (add 1 row and 1 clm for headers)
dat.import_PedigreeDietPrefRules             = zeros(1, (dat.num_LivingAndDetritus+1)); % initialize (add 1 clm for header)
dat.PedigreeDietPrefRules(2:end, 1)          = dat.EwENumberCode(1:dat.num_LivingAndDetritus); % producer group header
dat.PedigreeDietPrefRules(1, 2:end)          = dat.EwENumberCode(1:dat.num_LivingAndDetritus)'; % consumer group header
dat.PedigreeDietPrefRules(1, 1)              = NaN;
dat.import_PedigreeDietPrefRules(1)          = NaN;
dat.PedigreeDietPrefRules(2:(dat.num_LivingAndDetritus+1), 2:(dat.num_LivingAndDetritus+1)) = PedigreeDietPrefRules(1:dat.num_LivingAndDetritus, 1:dat.num_LivingAndDetritus); % this final dat.PedigreeDietPrefRules does not include import diet
dat.import_PedigreeDietPrefRules(2:(dat.num_LivingAndDetritus+1))                           = PedigreeDietPrefRules((dat.num_LivingAndDetritus+1), 1:dat.num_LivingAndDetritus); % next last row is import PedigreeDietPrefRules

% step 15d: pedigree scaling terms
dat.Pedigree_PhysiologyScaler = a(65);
dat.Pedigree_BiomassScaler    = a(66);
dat.Pedigree_FisheriesScaler  = a(67);
dat.Pedigree_DietScaler       = a(68);
dat.Pedigree_BAScaler         = a(69);
dat.Pedigree_EMScaler         = a(70);
dat.Pedigree_DiscardScaler    = a(71);
dat.Pedigree_minBiomass       = a(72);
dat.Pedigree_minPhysiology    = a(73);





% *************************************************************************
% STEP 16: parse functional response parameters----------------------------
%   NOTE: leaving parsing for future. clms 1-4 apply to all prey for each predator
%         clms 5-end are specific params for each trophic link (not yet defined)
dat.FunctionalResponseParams  = FunctionalResponseParams(:, 1:4);
dat.FunctionalResponse_matrix = FunctionalResponseParams(:, 5:end);





% end function*************************************************************